<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:latex="http://www.inria.fr/koala/XML/xslProcessor/Latex"
  version="1.0" >
<xsl:output encoding="ISO-8859-1" method="text" />

    <xsl:template match="book">
      <xsl:text>
\documentclass{report}
\usepackage{german} 
%--\usepackage[german]{babel} 
\setcounter{tocdepth}{2}
\begin{document}
\thispagestyle{empty}
\vfill
\begin{center}
\begin{minipage}{12cm}
\vspace{2cm}
\begin{center}
{\huge{\bf
      </xsl:text>
      <xsl:value-of select="title"/>
      <xsl:text>
}}\vspace{1cm}
{\large{\bf
      </xsl:text> 
      <xsl:apply-templates select="authors"/>
      <xsl:apply-templates select="organisation"/>
      <xsl:text>
}}\vspace{2cm}
\today \\
{\large
      </xsl:text>
      <xsl:text>Koordination:</xsl:text>
      <xsl:apply-templates select="managers"/>
      <xsl:text>
}
\end{center}
\vspace{2cm}
\end{minipage}
\end{center}
\vfill
\newpage
\thispagestyle{empty}
\mbox{ }
\cleardoublepage
\pagenumbering{roman}\setcounter{page}{3}
       </xsl:text>
       <xsl:apply-templates select="overview"/>
       <xsl:text>
\cleardoublepage
\tableofcontents
\clearpage
\pagenumbering{arabic}\setcounter{page}{5}
       </xsl:text>
       <xsl:apply-templates select="chapters"/>
       <xsl:apply-templates select="appendices"/>
       <xsl:apply-templates select="bibliography"/>
       <xsl:text>
\end{document}
       </xsl:text>
    </xsl:template>
    
    <xsl:template match="strong">
      <xsl:text>{\bf </xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>
    
    <xsl:template match="bf">
      <xsl:text>{\bf </xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>
    
    <xsl:template match="it">
      <xsl:text>{\it </xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>
    
    <xsl:template match="tt">
      <xsl:text>{\tt </xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>
    
    <xsl:template match="em">
      <xsl:text>{\em </xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>
    
    <xsl:template match="code">
      <xsl:text>\begin{center}\scriptsize
                \begin{verbatim}</xsl:text>
      <xsl:apply-templates/>
      <xsl:text>\end{verbatim}
                \end{center}</xsl:text>
    </xsl:template>
    
    <xsl:template match="var">
      <xsl:text>{\it </xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>

    <xsl:template match="newpage">
      <xsl:text>\newpage</xsl:text>
    </xsl:template>    

    <xsl:template match="list/item">
      <xsl:text>\item </xsl:text>
      <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="list[@type='unordered']">
      <xsl:text>\begin{itemize}</xsl:text>      
      <xsl:apply-templates/>
      <xsl:text>\end{itemize}</xsl:text>
    </xsl:template>

    <xsl:template match="list[@type='ordered']">
      <xsl:text>\begin{enumerate}</xsl:text>      
      <xsl:apply-templates/>
      <xsl:text>\end{enumerate}</xsl:text>
    </xsl:template>
    
    <xsl:template match="quote">
      <xsl:text>\begin{quotation}</xsl:text>
      <xsl:apply-templates/>
      <xsl:text>\end{quotation}</xsl:text>
    </xsl:template>
      
    <xsl:template match="note">
      <xsl:text>{\it </xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>
      
    <xsl:template match="warning">
      <xsl:text>\underline{\it </xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>
      
    <xsl:template match="list/item/list/item">
      <xsl:text>\subitem </xsl:text>
      <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="overview/title">
      <xsl:text>\chapter*{</xsl:text>
      <xsl:apply-templates/>
      <xsl:text>} </xsl:text>
    </xsl:template>

    <xsl:template match="chapter/title">
      <xsl:text>\chapter{</xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>

    <xsl:template match="section/title">
      <xsl:text>\section{</xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>

    <xsl:template match="section/section/title">
      <xsl:text>\subsection{</xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>

    <xsl:template match="section/section/section/title">
      <xsl:text>\subsubsection{</xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>

    <xsl:template match="appendix/title">
      <xsl:text>\chapter{</xsl:text>
      <xsl:apply-templates/>
      <xsl:text>}</xsl:text>
    </xsl:template>

    <xsl:template match="appendices">
      <xsl:text>\appendix</xsl:text>
      <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="bibliography">
    <xsl:text>
    \begin{thebibliography}{nn}
    </xsl:text>
      <xsl:apply-templates/>
    <xsl:text>
    \end{thebibliography}
    </xsl:text>
    </xsl:template>

    <xsl:template match="entry">
    <xsl:text>\bibitem{</xsl:text>
      <xsl:number level="single"/>
    <xsl:text>}{\bf </xsl:text>
      <xsl:apply-templates select="authors"/>
    <xsl:text>} \newblock {\em </xsl:text>
      <xsl:apply-templates select="title"/>
    <xsl:text>}, \newblock </xsl:text>
      <xsl:apply-templates select="publisher"/>
    <xsl:text>, </xsl:text>
      <xsl:apply-templates select="year"/>
      <xsl:apply-templates select="uri"/>
      <xsl:text>. </xsl:text>
    </xsl:template>

    <xsl:template match="bibliography//authors">
    <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="bibliography//author">
    <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="bibliography//year">
    <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="bibliography//publisher">
    <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="bibliography//uri">
    <xsl:text>\\ {\it URI not jet implemented}</xsl:text>
    <xsl:value-of select="@href"/>
    </xsl:template>

    <xsl:template match="author">
       <xsl:apply-templates/>
       <xsl:text>\\</xsl:text>
    </xsl:template>

    <xsl:template match="img">
      <xsl:text>\centerline{\scalebox{</xsl:text>
      <xsl:value-of select="@scale"/>
      <xsl:text>}{\includegraphics{</xsl:text>
      <xsl:value-of select="@href"/>
      <xsl:text>}}}</xsl:text>
    </xsl:template>

    <xsl:template match="manager">
       <xsl:apply-templates/>
       <xsl:text>\\</xsl:text>
    </xsl:template>

    <xsl:template match="organisation">
       <xsl:apply-templates/>
       <xsl:text>\\</xsl:text>
    </xsl:template>

</xsl:stylesheet>
